YARP 2.1.8 (2007-11-20)                                                {#v2_1_8}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.7...v2.1.8`):

```
    62	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     9	Lorenzo Natale <lorenzo.natale@iit.it>
     3	Giacomo Spigler <spiglerg@gmail.com>
     2	Alessandro Scalzo <alessandro.scalzo@iit.it>
     2	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	YARP Developers <yarp0-devel@lists.sourceforge.net>
```
